@@ -28,27 +28,44 @@
 *
 *  Called:  slDPAV
 *
-*  Patrick Wallace   Starlink   23 May 1997
+*  Last revision:   11 September 2005
+*
+*  Copyright P.T.Wallace.  All rights reserved.
+*
+*  License:
+*    This program is free software; you can redistribute it and/or modify
+*    it under the terms of the GNU General Public License as published by
+*    the Free Software Foundation; either version 2 of the License, or
+*    (at your option) any later version.
+*
+*    This program is distributed in the hope that it will be useful,
+*    but WITHOUT ANY WARRANTY; without even the implied warranty of
+*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*    GNU General Public License for more details.
+*
+*    You should have received a copy of the GNU General Public License
+*    along with this program (see SLA_CONDITIONS); if not, write to the
+*    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+*    Boston, MA  02110-1301  USA
 *
-*  Copyright (C) 1997 Rutherford Appleton Laboratory
 *  Copyright (C) 1995 Association of Universities for Research in Astronomy Inc.
 *-
 
       IMPLICIT NONE
 
-      REAL V1(3),V2(3)
+      REAL V1(3), V2(3)
 
       INTEGER I
-      DOUBLE PRECISION D1(3),D2(3)
+      DOUBLE PRECISION D1(3), D2(3)
 
       DOUBLE PRECISION slDPAV
 
 
-*  Call the double precision version
+*  Call the double precision version.
       DO I=1,3
-         D1(I)=V1(I)
-         D2(I)=V2(I)
+         D1(I) = V1(I)
+         D2(I) = V2(I)
       END DO
-      slPAV=slDPAV(D1,D2)
+      slPAV = REAL(slDPAV(D1,D2))
 
       END
