@@ -1,11 +1,13 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <ctype.h>
+#include <string.h>
+
 #define import_spp
 #define import_libc
 #define import_fset
 #define import_error
-#define import_ctype
 #define import_stdio
 #define import_alloc
 #define import_ttset
@@ -54,7 +56,6 @@ extern	int cldebug, cltrace;		/* debug/trace flags		     */
 extern	int lastjobno;			/* last background job spawned	     */
 extern	int gologout;			/* flag to execute() to cause logout */
 extern  int logout_status;      	/* optional arg to logout()          */
-extern	char *findexe();
 
 /* Device Allocation stuff (really should be in a separate package).
  */
@@ -348,11 +349,11 @@ clflprcache (void)
 	    if ((o.o_type & OT_BASIC) == OT_STRING) {
 		ltp = ltasksrch ("", o.o_val.v_s);
 		if (ltp->lt_flags & (LT_SCRIPT|LT_BUILTIN|LT_FOREIGN|LT_PSET))
-		    pid = NULL;
+		    pid = 0;
 		else
 		    pid = pr_pnametopid (findexe(ltp->lt_pkp,
 			ltp->lt_u.ltu_pname));
-		if (pid == NULL) {
+		if (pid == 0) {
 		    eprintf ("Warning: task `%s' not in cache\n", o.o_val.v_s);
 		    continue;
 		}
@@ -431,7 +432,6 @@ clchdir (void)
 	register struct pfile *pfp;
 	struct	operand o;
 	char	*dirname;
-	char	*index(), *envget();
 
 	pfp = newtask->t_pfp;
 	if (nargs (pfp) <= 0) {
