@@ -1,6 +1,8 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+
 #define import_spp
 #define import_libc
 #define import_stdio
@@ -621,7 +623,7 @@ fieldcvt (register char *f)
 	static char fctbl[] = {
 	    FN_NAME, FN_TYPE, FN_MODE, FN_VALUE, FN_MIN,
 	    FN_MAX, FN_PROMPT, FN_VALUE, FN_LENGTH, FN_VALUE,
-	    FN_XTYPE, NULL
+	    FN_XTYPE, '\0'
 	};
 
 	int kentry;
@@ -814,7 +816,6 @@ sexa (char *s)
 	int	n, sign;
 	int	hr, minutes;
 	float	sec;
-	extern double atof();
 
 	o.o_type = OT_REAL;
 	sign = (*s == '-') ? (s++, -1) : 1;
@@ -1213,7 +1214,7 @@ unsetigoto (int loc)
 {
 	int 	last, curr;
 
-	last = NULL;
+	last = 0;
 	curr = igoto1;
 
 	while (curr != loc) {
@@ -1221,7 +1222,7 @@ unsetigoto (int loc)
 	    curr = coderef(curr)->c_args;
 	}
 
-	if (last == NULL)
+	if (last == 0)
 	    igoto1 = coderef(curr)->c_args;
 	else
 	    coderef(last)->c_args = coderef(curr)->c_args;
