@@ -1,6 +1,8 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+
 #define	import_spp
 #define	import_libc
 #define	import_fset
@@ -12,6 +14,7 @@
 #define	import_prtype
 #define	import_xwhen
 #define import_xnames
+#define import_kproto
 #include <iraf.h>
 
 #include <ctype.h>
@@ -49,7 +52,6 @@
 #define	BKG_QUANTUM	30	/* period(sec) bkgjob checkup		*/
 #define	MAX_INTERRUPTS	5	/* max interrupts of a task		*/
 #define	LEN_INTRSTK	10	/* max nesting of saved interrupts	*/
-typedef	int (*PFI)();
 
 extern	int yydebug;		/* print each parser state if set	*/
 extern	FILE *yyin;		/* where parser reads from		*/
@@ -60,12 +62,12 @@ extern	int bkgno;		/* job number if bkg job		*/
 int	cldebug = 0;		/* print out lots of goodies if > 0	*/
 int	cltrace = 0;		/* trace instruction execution if > 0	*/
 
-static	PFI old_onipc;		/* X_IPC handler chained to onint()	*/
+static	funcptr_t old_onipc;	/* X_IPC handler chained to onint()	*/
 static	long *jumpcom;		/* IRAF Main setjmp/longjmp buffer	*/
 static	jmp_buf jmp_save;	/* save IRAF Main jump vector		*/
 static	jmp_buf jmp_clexit;	/* clexit() jumps here			*/
 static	int intr_sp;		/* interrupt save stack pointer		*/
-static	XINT intr_save[LEN_INTRSTK];	/* the interrupt save stack	*/
+static	funcptr_t intr_save[LEN_INTRSTK];/* the interrupt save stack	*/
 memel	cl_dictbuf[DICTSIZE];	/* the dictionary area			*/
 
 jmp_buf errenv;			/* cl_error() jumps here		*/
@@ -86,7 +88,7 @@ static void execute();
 static void login(), logout();
 static void startup(), shutdown();
 
-extern void c_xwhen(), onint();
+static void onint (int *vex, int (**next_handler)(void));
 extern int yyparse();
 
 
@@ -180,7 +182,7 @@ clshutdown (void)
 static void
 startup (void)
 {
-	void	onipc();
+	void	onipc(int *vex, funcptr_t *next_handler);
 
 	/* Set up pointers to dictionary buffer.
 	 */
@@ -194,7 +196,7 @@ startup (void)
 	/* Post exception handlers for interrupt and write to IPC with no
 	 * reader.  The remaining exceptions use the standard handler.
 	 */
-	c_xwhen (X_IPC, onipc, &old_onipc);
+	c_xwhen (X_IPC, (funcptr_t)onipc, &old_onipc);
 	intr_reset();
 
 	/* The following is a temporary solution to an initialization problem
@@ -346,11 +348,19 @@ login (char *cmd)
 	register char *ip, *op;
 	struct	ltask *ltp;
 	struct	operand o;
-	char	*loginfile = LOGINFILE;
+	char	loginfile[SZ_PATHNAME];
 	char	alt_loginfile[SZ_PATHNAME];
 	char	clstartup[SZ_PATHNAME];
 	char	clprocess[SZ_PATHNAME];
 	char	*arglist;
+	char    *loginfiles[] = {
+	    LOGINFILE,
+	    "HOME$/.iraf/" LOGINFILE,
+	    "/etc/iraf/" LOGINFILE,
+	    "hlib$" LOGINFILE,
+	    NULL
+	};
+	int i;
 
 	strcpy (clstartup, HOSTLIB);
 	strcat (clstartup, CLSTARTUP);
@@ -466,28 +476,21 @@ login (char *cmd)
 		compile (EXEC);
 	    }
 
-        } else if (c_access (loginfile,0,0) == NO) {
-            char *home = envget ("HOME");
-            char global[SZ_LINE];
-
-            memset (global, 0, SZ_LINE);
-            sprintf (global, "%s/.iraf/login.cl", home);
-            if (c_access (global, 0, 0) == YES) {
-                o.o_val.v_s = global;
-                compile (CALL, "cl");
-                compile (PUSHCONST, &o);
-                compile (REDIRIN);
-                compile (EXEC);
-            } else {
-                printf ("Warning: no login.cl found in login directory\n");
-            }
-
-	} else {
-	    o.o_val.v_s = loginfile;
-	    compile (CALL, "cl");
-	    compile (PUSHCONST, &o);
-	    compile (REDIRIN);
-	    compile (EXEC);
+        } else {
+	    for (i = 0; loginfiles[i] != NULL; i++) {
+		c_fmapfn (loginfiles[i], loginfile, SZ_PATHNAME);
+		if (c_access (loginfile,0,0) == YES) {
+		    o.o_val.v_s = loginfile;
+		    compile (CALL, "cl");
+		    compile (PUSHCONST, &o);
+		    compile (REDIRIN);
+		    compile (EXEC);
+		    break;
+		}
+	    }
+	    if (loginfiles[i] == NULL) {
+		printf("Warning: no login.cl found.\n");
+	    }
 	}
 
 	compile (END);
@@ -567,7 +570,7 @@ memneed (
  *   before shutting down.
  */
 /* ARGSUSED */
-void
+static void
 onint (
   int	*vex,			/* virtual exception code	*/
   int	(**next_handler)(void) 	/* next handler to be called	*/
@@ -631,12 +634,12 @@ onint (
 void
 intr_disable (void)
 {
-	PFI	junk;
+	funcptr_t	junk;
 
 	if (intr_sp >= LEN_INTRSTK)
 	    cl_error (E_IERR, "interrupt save stack overflow");
 	c_xwhen (X_INT, X_IGNORE, &junk);
-	intr_save[intr_sp++] = (XINT) junk;
+	intr_save[intr_sp++] = junk;
 }
 
 
@@ -646,7 +649,7 @@ intr_disable (void)
 void
 intr_enable (void)
 {
-	PFI	junk;
+	funcptr_t	junk;
 
 	if (--intr_sp < 0)
 	    cl_error (E_IERR, "interrupt save stack underflow");
@@ -660,9 +663,9 @@ intr_enable (void)
 void
 intr_reset (void)
 {
-	PFI	junk;
+	funcptr_t	junk;
 
-	c_xwhen (X_INT, onint, &junk);
+	c_xwhen (X_INT, (funcptr_t)onint, &junk);
 	intr_sp = 0;
 }
 
