@@ -1,11 +1,13 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <ctype.h>
+#include <string.h>
+
 #define import_spp
 #define import_libc
 #define import_fset
 #define import_error
-#define import_ctype
 #define import_stdio
 #define import_alloc
 #define import_ttset
@@ -56,7 +58,6 @@ extern	int gologout;			/* flag to execute() to cause logout */
 extern  int logout_status;      	/* optional arg to logout()          */
 extern  int errorline;			/* error recover line		     */
 extern  int currentline;		/* line currently being executed     */
-extern	char *findexe();
 
 extern	int do_error;			/* for error recovery/trapping 	     */
 
@@ -352,11 +353,11 @@ clflprcache (void)
 	    if ((o.o_type & OT_BASIC) == OT_STRING) {
 		ltp = ltasksrch ("", o.o_val.v_s);
 		if (ltp->lt_flags & (LT_SCRIPT|LT_BUILTIN|LT_FOREIGN|LT_PSET))
-		    pid = NULL;
+		    pid = 0;
 		else
 		    pid = pr_pnametopid (findexe(ltp->lt_pkp,
 			ltp->lt_u.ltu_pname));
-		if (pid == NULL) {
+		if (pid == 0) {
 		    eprintf ("Warning: task `%s' not in cache\n", o.o_val.v_s);
 		    continue;
 		}
@@ -385,7 +386,7 @@ flpr_task (char *task)
 
 	ltp = ltasksrch ("", task);
 	if (ltp->lt_flags & (LT_SCRIPT|LT_BUILTIN|LT_FOREIGN|LT_PSET))
-	    pid = NULL;
+	    pid = 0;
 	else
 	    pid = pr_pnametopid (findexe(ltp->lt_pkp, ltp->lt_u.ltu_pname));
 
@@ -457,7 +458,6 @@ clchdir (void)
 	register struct pfile *pfp;
 	struct	operand o;
 	char	*dirname;
-	char	*index(), *envget();
 
 	pfp = newtask->t_pfp;
 	if (nargs (pfp) <= 0) {
@@ -2246,7 +2246,7 @@ clonerror (void)
 	extern  char *onerr_handler;
 
 
-	handler[0] = NULL;
+	handler[0] = '\0';
 	pushbparams (pfp->pf_pp);
 	if (nargs(pfp) > 0) {
 	    popop();			/* discard the $n name		*/
