@@ -1,6 +1,8 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+
 #define import_spp
 #define import_libc
 #define import_stdio
@@ -45,8 +47,6 @@ long int run_level 	= 0;
 int 	do_error  	= YES;
 char	*onerr_handler  = NULL;
 
-char	*findexe();
-
 
 /* RUN -- Run the code beginning at pc until we run an EXEC instruction of
  *   something other than a builtin command or END instruction.
