@@ -1,6 +1,8 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+
 #define import_spp
 #define import_libc
 #define import_stdio
@@ -721,7 +723,7 @@ fieldcvt (register char *f)
 	static char fctbl[] = {
 	    FN_NAME, FN_TYPE, FN_MODE, FN_VALUE, FN_MIN,
 	    FN_MAX, FN_PROMPT, FN_VALUE, FN_LENGTH, FN_VALUE,
-	    FN_XTYPE, NULL
+	    FN_XTYPE, '\0'
 	};
 
 	int kentry;
@@ -918,8 +920,6 @@ intrfunc (char *fname, int nargs)
 		{
 		    int	o1, o2;
 		    struct operand istr;
-		    char *index();
-		    extern void *memset();
 trim_:
 		    if (nargs >= 2) {
 		        /* Get the chars to trim, otherwise its whitespace.  */
@@ -933,9 +933,9 @@ trim_:
 
 		    memset (sbuf, 0, SZ_LINE);
 		    if (trim_side & TRIM_LEFT)
-			while (index (trim, (int)istr.o_val.v_s[o1])) o1++;
+			while (strchr (trim, (int)istr.o_val.v_s[o1])) o1++;
 		    if (trim_side & TRIM_RIGHT) {
-			while (index (trim, (int)istr.o_val.v_s[o2])) o2--;  
+			while (strchr (trim, (int)istr.o_val.v_s[o2])) o2--;  
 			istr.o_val.v_s[++o2] = '\0';
 		    }
 		    strncpy (sbuf, &istr.o_val.v_s[o1], o2-o1+1);
@@ -1009,7 +1009,6 @@ sexa (char *s)
 	int	n, sign;
 	int	hr, minutes;
 	float	sec;
-	extern double atof();
 
 	o.o_type = OT_REAL;
 	sign = (*s == '-') ? (s++, -1) : 1;
@@ -1408,7 +1407,7 @@ unsetigoto (int loc)
 {
 	int 	last, curr;
 
-	last = NULL;
+	last = 0;
 	curr = igoto1;
 
 	while (curr != loc) {
@@ -1416,7 +1415,7 @@ unsetigoto (int loc)
 	    curr = coderef(curr)->c_args;
 	}
 
-	if (last == NULL)
+	if (last == 0)
 	    igoto1 = coderef(curr)->c_args;
 	else
 	    coderef(last)->c_args = coderef(curr)->c_args;
