@@ -1,12 +1,15 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+
 #define	import_spp
 #define	import_libc
 #define	import_stdio
 #define	import_error
 #define	import_finfo
 #define	import_prstat
+#define import_kproto
 #include <iraf.h>
 
 #include "config.h"
@@ -64,8 +67,6 @@
 extern	int	cldebug;
 extern	int	cltrace;
 
-typedef	XINT (*PFI)();
-
 struct process {
 	int	pr_pid;			/* process id of subprocess	*/
 	long	pr_time;		/* time when process executed	*/
@@ -195,7 +196,6 @@ pr_pconnect (
 	struct	process *pr_findproc();
 	struct	_finfo fi;
 	int	fd_in, fd_out;
-	extern  int c_finfo (char *name, struct _finfo *fi);
 
 	if (pr_head == NULL)
 	    pr_initcache();
@@ -241,7 +241,7 @@ pr_pconnect (
 	    intr_disable();
 	    if ((pr->pr_pid = c_propen (process, &fd_in, &fd_out)) == NULL) {
 		intr_enable();
-		return (NULL);
+		return (0);
 	    }
 	    intr_enable();
 
@@ -274,7 +274,7 @@ pr_pdisconnect (struct process *pr)
 	/* Ignore attempts to dump active processes.  This might happen
 	 * when an active process executes a command which calls dumpcache.
 	 */
-	if (pr == NULL || pr->pr_pid == NULL || pr_busy(pr))
+	if (pr == NULL || pr->pr_pid == 0 || pr_busy(pr))
 	    return;
 
 	if (cltrace)
@@ -312,7 +312,7 @@ pr_setcache (int new_szprcache)
 	     * then dump the cache.
 	     */
 	    for (pr=pr_head;  pr != NULL;  pr=pr->pr_dn)
-		if (pr->pr_pid != NULL && (pr->pr_flags & P_LOCKED))
+		if (pr->pr_pid != 0 && (pr->pr_flags & P_LOCKED))
 		    strcpy (pname[nprocs++], pr->pr_name);
 	    pr_dumpcache (0, 1);
 	}
@@ -351,7 +351,7 @@ pr_findproc (char *process)
 	struct	process *pr;
 
 	for (pr=pr_head;  pr != NULL;  pr=pr->pr_dn) {
-	    if (pr->pr_pid != NULL && pr_idle(pr))
+	    if (pr->pr_pid != 0 && pr_idle(pr))
 		if (strcmp (process, pr->pr_name) == 0)
 		    return (pr);
 	}
@@ -376,7 +376,7 @@ pr_cachetask (
 	ltp = ltasksrch ("", ltname);
 	if (ltp->lt_flags & (LT_SCRIPT|LT_BUILTIN))
 	    return (ERR);
-	if ((pid = pr_pnametopid(findexe(ltp->lt_pkp,ltp->lt_pname))) == NULL) {
+	if ((pid = pr_pnametopid(findexe(ltp->lt_pkp,ltp->lt_pname))) == 0) {
 	    pid = pr_connect (findexe(ltp->lt_pkp,ltp->lt_pname), "\n", &fdummy,
 		&fdummy, stdin, stdout, stderr, 0,0,0, 0);
 	    pr_disconnect (pid);
@@ -397,7 +397,7 @@ pr_lock (
 {
 	struct process *pr;
 
-	if (pid != NULL) {
+	if (pid != 0) {
 	    for (pr=pr_head;  pr != NULL;  pr=pr->pr_dn)
 		if (pr->pr_pid == pid) {
 		    pr->pr_flags |= P_LOCKED;
@@ -419,7 +419,7 @@ pr_unlock (
 {
 	struct process *pr;
 
-	if (pid != NULL)
+	if (pid != 0)
 	    for (pr=pr_head;  pr != NULL;  pr=pr->pr_dn)
 		if (pr->pr_pid == pid)
 		    return (pr->pr_flags &= ~P_LOCKED);
@@ -533,7 +533,7 @@ pr_getpno (void)
 
 
 /* PR_PNAMETOPID -- Lookup the named process in the cache and return the pid
- * if found, NULL otherwise.
+ * if found, 0 otherwise.
  */
 int
 pr_pnametopid (char *pname)
@@ -559,9 +559,9 @@ pr_chdir (register int pid, char *newdir)
 
 	pr_checkup();
 	for (pr=pr_head;  pr != NULL;  pr=pr->pr_dn) {
-	    if (pr->pr_pid == NULL || !pr_idle(pr))
+	    if (pr->pr_pid == 0 || !pr_idle(pr))
 		continue;
-	    else if (pid == NULL || pr->pr_pid == pid)
+	    else if (pid == 0 || pr->pr_pid == pid)
 		c_prchdir (pr->pr_pid, newdir);
 	}
 }
@@ -577,9 +577,9 @@ pr_envset (register int pid, char *envvar, char *valuestr)
 
 	pr_checkup();
 	for (pr=pr_head;  pr != NULL;  pr=pr->pr_dn) {
-	    if (pr->pr_pid == NULL || !pr_idle(pr))
+	    if (pr->pr_pid == 0 || !pr_idle(pr))
 		continue;
-	    else if (pid == NULL || pr->pr_pid == pid)
+	    else if (pid == 0 || pr->pr_pid == pid)
 		c_prenvset (pr->pr_pid, envvar, valuestr);
 	}
 }
@@ -600,7 +600,7 @@ pr_checkup (void)
 	 * causing premature termination.
 	 */
 	for (pr=pr_cache, n=sz_prcache;  --n >= 0;  pr++) {
-	    if (pr->pr_pid != NULL) {
+	    if (pr->pr_pid != 0) {
 		if (c_prstati (pr->pr_pid, PR_STATUS) == P_DEAD) {
 		    pr->pr_flags = 0;
 		    pr_pdisconnect (pr);
@@ -619,13 +619,13 @@ pr_checkup (void)
 void
 onipc (
     int *vex,			/* virtual exception code	*/
-    PFI *next_handler		/* next handler to be called	*/
+    funcptr_t *next_handler	/* next handler to be called	*/
 )
 {
 	register struct	process *pr;
 
 	for (pr=pr_head;  pr != NULL;  pr=pr->pr_dn) {
-	    if (pr->pr_pid != NULL) {
+	    if (pr->pr_pid != 0) {
 		if (c_prstati (pr->pr_pid, PR_STATUS) == P_DEAD)
 		    break;
 	    }
