@@ -1,3 +1,6 @@
+#include <string.h>
+#include <stdlib.h>
+
 #define import_spp
 #define import_knames
 #include <iraf.h>
