@@ -1,19 +1,24 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+#include <stdlib.h>
+
 #define	import_spp
 #define import_knames
-#include <stdlib.h>
 #include <iraf.h>
 
 
 /* ISCL32 - Scale a pixel array stored as SPP chars to the desired type.
  */
-ISCL32 (a, b, npix, bscale, bzero)
-XCHAR	*a;			/* input array			*/
-XCHAR	*b;			/* output array			*/
-XINT	*npix;			/* number of bytes to swap	*/
-XDOUBLE *bscale, *bzero;	/* scaling factors		*/
+void
+ISCL32 (
+    XCHAR	*a,		/* input array			*/
+    XCHAR	*b,		/* output array			*/
+    XINT	*npix,		/* number of bytes to swap	*/
+    XDOUBLE *bscale, 
+    XDOUBLE *bzero		/* scaling factors		*/
+)
 {
     int   i, pix;
     int   *ip = (int *) a;
