@@ -1,13 +1,16 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <sys/stat.h>		/* for mkdir()	*/
 #include "bootlib.h"
 
 /* OS_CREATEDIR -- Create a new subdirectory.
  */
-os_createdir (dirname, mode)
-char	*dirname;
-int	mode;
+int
+os_createdir (
+  char	*dirname,
+  int	mode
+)
 {
 	if (bdebug)
 	    fprintf (stderr, "createdir '%s'\n", dirname);
