@@ -2,6 +2,7 @@
  */
 
 #include <string.h>
+#include <ctype.h>
 #include "bootlib.h"
 
 /* Uncomment the following if the kernel for this machine does not need
@@ -14,10 +15,6 @@
 #define	irafpath os_irafpath
 #endif
 
-char	*irafpath(char *sysfile);
-char	*os_getenv(char *envvar);
-extern  int  os_access (char *fname, int mode, int type);
-
 
 /* OS_SYSFILE -- Return the pathname of a system library file.  The library
  * search order is
