@@ -31,7 +31,7 @@
 #define	LIBTOOL		"libtool"
 #define	LIBFLAGS	"r"
 #define	REBUILD		"ranlib"
-#define	XC		"xc"
+#define	XC		"xc.e"
 #define	INTERRUPT	SYS_XINT
 
 extern	char *makeobj(char *fname);
@@ -44,7 +44,7 @@ char	*resolvefname(char *fname);
 char	*mkpath(char *module, char *directory, char *outstr);
 
 int   h_updatelibrary (char *library, char *flist[], int totfiles, 
-                char *xflags, char *irafdir);
+                char *xflags);
 int   h_rebuildlibrary (char *library);
 int   h_incheck (char *file, char *dir);
 int   h_outcheck (char *file, char *dir, int clobber);
@@ -82,8 +82,7 @@ h_updatelibrary (
     char   *library,		/* pathname of library		*/
     char   *flist[],		/* pointers to filename strings	*/
     int	    totfiles,		/* number of files in list	*/
-    char   *xflags,		/* XC compiler flags		*/
-    char   *irafdir 		/* iraf root directory		*/
+    char   *xflags		/* XC compiler flags		*/
 )
 {
 	char	cmd[SZ_CMD+1], *args;
@@ -91,6 +90,11 @@ h_updatelibrary (
 	int	nsources, nfiles, ndone, nleft;
 	int	hostnames, status;
 	char	libfname[SZ_PATHNAME+1];
+	static  char xc_path[SZ_PATHNAME+1];
+
+        if (!xc_path[0])
+            if (os_sysfile (XC, xc_path, SZ_PATHNAME) <= 0)
+                strcpy (xc_path, XC);
 
 	/* Get the library file name. */
 	h_getlibname (library, libfname);
@@ -100,10 +104,7 @@ h_updatelibrary (
 	 * Compile the files.
 	 * -------------------
 	 */
-	if (irafdir[0])
-	    sprintf (cmd, "%s -r %s %s", XC, irafdir, xflags);
-	else
-	    sprintf (cmd, "%s %s", XC, xflags);
+	sprintf (cmd, "%s %s", xc_path, xflags);
 
 	if (debug)
 	    strcat (cmd, " -d");
@@ -147,6 +148,8 @@ h_updatelibrary (
 		if ((status = os_cmd (cmd)) != OK) {
 		    if (status == INTERRUPT)
 			fatals ("<ctrl/c> interrupt %s", library);
+		    if (status != OK)
+		        errors ("Command '%s' returned error", cmd);
 		    if (!ignore)
 			baderr++;
 		    exit_status += status;
@@ -212,8 +215,11 @@ h_updatelibrary (
 
 		    for (i=0;  i < nfiles;  i++)
 			os_delete (makeobj (flist[ndone+i]));
-		} else if (exit_status == INTERRUPT)
+		} else if (exit_status == INTERRUPT) {
 		    fatals ("<ctrl/c> interrupt %s", library);
+		} else {
+	            errors ("Command '%s' returned error", cmd);
+		}
 	    }
 
 	    /* Truncate command and repeat with the next few files.
