@@ -25,8 +25,9 @@
 #define	XFLAGS		"xflags"
 #define	XVFLAGS		"xvflags"
 #define	DEBUGSYM	"debug"
-#define	XC		"xc"
-#define	GENERIC		"generic"
+#define	XC		"xc.e"
+#define	GENERIC		"generic.e"
+#define XYACC		"xyacc.e"
 #define	GFLAGS		"gflags"
 #define	BACK		".."
 
@@ -124,6 +125,7 @@ char	*k_fgets(char *op, int maxch, register struct context *cx);
 
 /*  main.c  */
 void warns (char *fmt, char *arg);
+void errors (char *fmt, char *arg);
 void fatals (char *fmt, char *arg);
 
 
@@ -157,7 +159,7 @@ int   fn_strncpy (char *out, char *in, int maxch);
 
 /*  host.c  */ 
 int   h_updatelibrary (char *library, char *flist[], int totfiles, 
-		char *xflags, char *irafdir);
+		char *xflags);
 int   h_rebuildlibrary (char *library);
 int   h_incheck (char *file, char *dir);
 int   h_outcheck (char *file, char *dir, int clobber);
@@ -217,6 +219,7 @@ void  do_omake (struct context *cx, char *fname);
 int   do_xc (struct context *cx);
 int   do_link (struct context *cx);
 int   do_generic (struct context *cx);
+int   do_xyacc (struct context *cx);
 void  do_set (struct context *cx);
 int   do_incheck (struct context *cx);
 int   do_outcheck (struct context *cx);
