@@ -46,7 +46,7 @@ do_mkpkg (
 		topcx = cx->prev;
 
 	    sprintf (fname, "%s%s", cx->curdir, cx->mkpkgfile);
-	    warns ("cannot open `%s'", fname);
+	    errors ("cannot open `%s'", fname);
 
 	    topcx = save_cx;
 	    return (ERR);
@@ -147,7 +147,7 @@ scan_modlist (
 	     * library is possible.
 	     */
 	    if ((exit_status = h_scanlibrary (cx->library)) != OK) {
-		warns ("error reading library file `%s'", cx->library);
+		errors ("error reading library file `%s'", cx->library);
 		return (ERR);
 	    }
 	}
@@ -328,7 +328,7 @@ next_:	    tok = gettok (cx, token, SZ_FNAME);
 		    /* Compile the modules and update the library.
 		     */
 		    exit_status = h_updatelibrary (cx->libpath,
-			cx->flist, cx->nfiles, getsym(XFLAGS), irafdir);
+			cx->flist, cx->nfiles, getsym(XFLAGS));
 		    if (exit_status == INTERRUPT)
 			fatals ("<ctrl/c> interrupt %s", cx->library);
 		    cx->totfiles += cx->nfiles;
@@ -364,7 +364,7 @@ next_:	    tok = gettok (cx, token, SZ_FNAME);
 	 * been reached (but only if the module being processed is a library
 	 * list).
 	 */
-	if (cx->totfiles == 0 && !forceupdate) {
+	if (cx->totfiles == 0) {
 	    printf ("Library %s is up to date\n", cx->library);
 	    fflush (stdout);
 	} else if (exit_status == OK || ignore) {
@@ -372,6 +372,8 @@ next_:	    tok = gettok (cx, token, SZ_FNAME);
 	     */
 	    if ((exit_status = h_rebuildlibrary (cx->library)) == INTERRUPT)
 		fatals ("<ctrl/c> interrupt %s", cx->library);
+	    if (exit_status != OK)
+	        errors ("Error rebuilding library %s", cx->library);
 	    printf ("Updated %d files in %s\n", cx->totfiles, cx->library);
 	    fflush (stdout);
 	}
@@ -544,13 +546,8 @@ push_context (
 	    strcat (ncx->curdir, newdir);
 	    strcat (ncx->curdir, "/");
 
-	    if (debug) {
-		printf ("change directory to `%s'\n", newdir);
-		fflush (stdout);
-	    }
-
 	    if (os_chdir (newdir) == ERR) {
-		warns ("cannot access subdirectory `%s'", newdir);
+		errors ("cannot access subdirectory `%s'", newdir);
 		free (ncx);
 		return (NULL);
 	    } else {
@@ -558,6 +555,9 @@ push_context (
 		ncx->level++;
 	    }
 
+	    printf ("mkpkg[%d]: Entering directory `%s'\n",
+		    ncx->level, ncx->dirpath);
+
 	    /* Initialize the file date cache, since the filenames therein
 	     * often reference the current directory.
 	     */
@@ -594,6 +594,10 @@ pop_context (
 	    level = cx->level;
 	    pcx   = cx->prev;
 
+	    if (level > pcx->level)
+	        printf ("mkpkg[%d]: Leaving directory `%s'\n",
+			cx->level, cx->dirpath);
+
 	    root_modlist = (strcmp (cx->library, pcx->library) != 0);
 	    if (!root_modlist)
 		pcx->totfiles += cx->totfiles;
@@ -609,11 +613,6 @@ pop_context (
 	    iflev    = cx->old_iflev;
 
 	    if (level > pcx->level) {
-		if (debug) {
-		    printf ("chdir ..\n");
-		    fflush (stdout);
-		}
-
 		if (os_chdir (pcx->dirpath) == ERR)
 		    fatals ("cannot return from subdirectory", cx->curdir);
 
@@ -657,13 +656,13 @@ get_dependency_list (
 		goto done;
 	    case TOK_FNAME:
 		if (nfiles >= MAX_DEPFILES)
-		    warns ("too many dependency files for module `%s'", module);
+		    errors ("too many dependency files for module `%s'", module);
 		dflist[nfiles++] = putstr (fname);
 		break;
 	    case TOK_END:
-		warns ("unexpected EOF in dependency list for `%s'", module);
+		errors ("unexpected EOF in dependency list for `%s'", module);
 	    default:
-		warns ("bad token `%s' in dependency list", fname);
+		errors ("bad token `%s' in dependency list", fname);
 	    }
 	}
 
@@ -705,7 +704,7 @@ up_to_date (
 )
 {
 	long	armod_date, newest_date, date;
-	long	h_ardate();
+	long	h_ardate(char *fname);
 	char	*fname;
 	int	old, i;
 
@@ -765,7 +764,7 @@ int
 open_mkpkgfile (register struct context *cx)
 {
 	register char	*fname = cx->mkpkgfile;
-	struct	context *find_mkpkgfile();
+	struct	context *find_mkpkgfile(struct context *head_cx, char *mkpkgfile, int level);
 	struct	context *ax;
 	
 	if (strcmp (fname, "stdin") == 0 || strcmp (fname, "STDIN") == 0) {
@@ -792,7 +791,7 @@ open_mkpkgfile (register struct context *cx)
 void
 close_mkpkgfile (register struct context *cx)
 {
-	struct context *find_mkpkgfile();
+	struct context *find_mkpkgfile(struct context *head_cx, char *mkpkgfile, int level);
 
 	if (cx->fp != stdin)
 	    if (find_mkpkgfile (cx->prev, cx->mkpkgfile, cx->level) == NULL)
@@ -832,7 +831,7 @@ search_mkpkgfile (register struct context *cx)
 {
 	char	word1[SZ_FNAME+1], word2[SZ_FNAME+1];
 	char	*prev, *curr, *temp;
-	int	tok, gettok();
+	int	tok, gettok(register struct context *cx, char *outstr, int maxch);
 
 	if (debug) {
 	    printf ("search_mkpkgfile (file=%s, library=%s)\n",
