@@ -221,6 +221,8 @@ do_osescape (register struct context *cx)
 	    exit_status = os_cmd (cmd);
 	if (exit_status == INTERRUPT)
 	    fatals ("<ctrl/c> interrupt %s", cx->library);
+	if (exit_status != OK)
+	    errors ("Command '%s' returned error", cmd);
 }
 
 
@@ -276,6 +278,8 @@ do_ppdir (
 	    do_delete (cx);
 	else if (strncmp (token, "$generic",	8) == 0)
 	    do_generic (cx);
+	else if (strncmp (token, "$xyacc",	6) == 0)
+	    do_xyacc (cx);
 	else if (strncmp (token, "$link",	5) == 0)
 	    do_link (cx);
 	else if (strncmp (token, "$move",	5) == 0)
@@ -294,7 +298,7 @@ do_ppdir (
 	    verbose = (strcmp (getargs(cx), "off") != 0);
 
 	else
-	    warns ("illegal preprocessor directive `%s'", token);
+	    errors ("illegal preprocessor directive `%s'", token);
 }
 
 
@@ -308,7 +312,7 @@ do_if (struct context *cx, char	*keyword)
 	register char	*op;
 	char	tokbuf[SZ_COMMAND+1];
 	char	buf[SZ_PREDBUF], *argv[MAX_ARGS];
-	long    fdate, altdate, os_fdate();
+	long    fdate, altdate, os_fdate(char *);
 	int	argc, negate, bval, i;
 	char	*key;
  
@@ -331,9 +335,9 @@ do_if (struct context *cx, char	*keyword)
 	 */
 	while ((ch = m_getc(cx)) != '(')
 	    if (ch == '\n')
-		warns ("illegal `%s' predicate", keyword);
+		errors ("illegal `%s' predicate", keyword);
 	    else if (ch == EOF)
-		warns ("unexpected EOF in `%s'", keyword);
+		errors ("unexpected EOF in `%s'", keyword);
 
 	argv[0] = buf;
 	op      = buf;
@@ -347,9 +351,9 @@ do_if (struct context *cx, char	*keyword)
 		else
 		    *op++ = ch;
 	    } else if (ch == '\n') {
-		warns ("missing right paren in `%s'", keyword);
+		errors ("missing right paren in `%s'", keyword);
 	    } else if (ch == EOF) {
-		warns ("unexpected EOF in `%s'", keyword);
+		errors ("unexpected EOF in `%s'", keyword);
 	    } else if (ch == ' ') {
 		continue;
 	    } else if (ch == SYSFILE_BEGIN && op == argv[argc]) {
@@ -362,9 +366,9 @@ do_if (struct context *cx, char	*keyword)
 	    } else if (ch == ':' || ch == ',') {
 		*op++ = EOS;
 		if (op - buf >= SZ_PREDBUF)
-		    warns ("predicate too large in `%s'", keyword);
+		    errors ("predicate too large in `%s'", keyword);
 		if (++argc >= MAX_ARGS)
-		    warns ("too many arguments in `%s' predicate", keyword);
+		    errors ("too many arguments in `%s' predicate", keyword);
 		argv[argc] = op;
 	    } else
 		*op++ = ch;
@@ -374,7 +378,7 @@ do_if (struct context *cx, char	*keyword)
 	argc++;
 
 	if (++iflev > SZ_IFSTACK)
-	    warns ("$IFs nested too deeply (%s)", keyword);
+	    errors ("$IFs nested too deeply (%s)", keyword);
 
 	/* If the $IF is encountered while scanning the tokens in a false-IF
 	 * clause, do not "execute" the $IF.  We still have to push the IF
@@ -409,7 +413,7 @@ do_if (struct context *cx, char	*keyword)
 		if ((valstr = getsym (argv[0])) == NULL &&
 		    (valstr = os_getenv (argv[0])) == NULL) {
 
-		    warns ("symbol `%s' not found", argv[0]);
+		    errors ("symbol `%s' not found", argv[0]);
 		    bval = 0;
 
 		} else {
@@ -490,7 +494,7 @@ do_if (struct context *cx, char	*keyword)
 	    bval = (exit_status != OK);
 
 	} else
-	    warns ("unrecognized $if statement `%s'", keyword);
+	    errors ("unrecognized $if statement `%s'", keyword);
 
 	if (negate)
 	    bval = !bval;
@@ -522,7 +526,7 @@ do_else (struct	context *cx)
 	}
 
 	if (iflev < 1)
-	    warns ("%s with no matching $if", "$else");
+	    errors ("%s with no matching $if", "$else");
 	else if (iflev > 1 && ifstate[iflev-1] == STOP)
 	    return;
 	else
@@ -542,7 +546,7 @@ do_endif (struct context *cx)
 	}
 
 	if (--iflev < 0)
-	    warns ("unmatched %s", "$endif");
+	    errors ("unmatched %s", "$endif");
 }
 
 
@@ -594,7 +598,7 @@ do_call (
 	int	old_nsymbols;
 
 	strcpy (modspec, program);
-	if (debug && ifstate[iflev] == PASS) {
+	if (ifstate[iflev] == PASS) {
 	    printf ("$call %s\n", modspec);
 	    fflush (stdout);
 	}
@@ -625,7 +629,7 @@ do_call (
 	/* Restore the old context and discard the argument temporaries.
 	 */
 	if (exit_status != OK)
-	    warns ("module `%s' not found or returned error", modspec);
+	    errors ("module `%s' not found or returned error", modspec);
 
 	cp = old_cp;
 	nsymbols = old_nsymbols;
@@ -685,7 +689,7 @@ do_goto (struct context *cx, char *symbol)
 	    }
 	}
 
-	warns ("could not find mkpkg module or label `%s'", symbol);
+	errors ("could not find mkpkg module or label `%s'", symbol);
 	if (cx->fp != stdin)
 	    k_fseek (cx, fpos, 0);
 
@@ -739,6 +743,11 @@ do_omake (
 	char	*s_xflags, *dfile;
 	long	sourcedate, objdate, date;
 	int	recompile, i;
+	static  char xc_path[SZ_PATHNAME+1];
+
+        if (!xc_path[0])
+            if (os_sysfile (XC, xc_path, SZ_PATHNAME) <= 0)
+                strcpy (xc_path, XC);
 
 
 	if (ifstate[iflev] == STOP)
@@ -750,7 +759,7 @@ do_omake (
 	}
 
 	if ((sourcedate = os_fdate (fname)) <= 0) {
-	    warns ("file `%s' not found", fname);
+	    errors ("file `%s' not found", fname);
 	    exit_status = ERR;
 	    return;
 
@@ -782,10 +791,7 @@ do_omake (
 		strcat (xflags, "-x ");
 	    strcat (xflags, s_xflags);
 
-	    if (irafdir[0])
-		sprintf (cmd, "%s %s -r %s %s", XC, xflags, irafdir, fname);
-	    else
-		sprintf (cmd, "%s %s %s", XC, xflags, fname);
+	    sprintf (cmd, "%s %s %s", xc_path, xflags, fname);
 
 	    if (verbose) {
 		printf ("%s\n", cmd);
@@ -796,6 +802,8 @@ do_omake (
 		exit_status = h_xc (cmd);
 	    if (exit_status == INTERRUPT)
 		fatals ("<ctrl/c> interrupt %s", cx->library);
+	    if (exit_status != OK)
+	        errors ("Command '%s' returned error", cmd);
 
 	} else if (verbose) {
 	    printf ("Object %s is up to date\n", makeobj(fname));
@@ -811,6 +819,11 @@ int
 do_xc (struct context *cx)
 {
 	char	cmd[SZ_CMD+1];
+	static  char xc_path[SZ_PATHNAME+1];
+
+        if (!xc_path[0])
+            if (os_sysfile (XC, xc_path, SZ_PATHNAME) <= 0)
+                strcpy (xc_path, XC);
 
 
 	if (debug > 1) {
@@ -818,10 +831,7 @@ do_xc (struct context *cx)
 	    fflush (stdout);
 	}
 
-	if (irafdir[0])
-	    sprintf (cmd, "%s -r %s", XC, irafdir);
-	else
-	    sprintf (cmd, "%s", XC);
+	sprintf (cmd, "%s", xc_path);
 
 	if (debug)
 	    strcat (cmd, " -d");
@@ -842,6 +852,8 @@ do_xc (struct context *cx)
 	    exit_status = h_xc (cmd);
 	if (exit_status == INTERRUPT)
 	    fatals ("<ctrl/c> interrupt %s", cx->library);
+	if (exit_status != OK)
+	    errors ("Command '%s' returned error", cmd);
 
 	return (exit_status);
 }
@@ -861,6 +873,11 @@ do_link (struct context *cx)
 	char *cmd = cmdbuf;
 	int lflags_set = 0;
 	char *lflags;
+	static  char xc_path[SZ_PATHNAME+1];
+
+        if (!xc_path[0])
+            if (os_sysfile (XC, xc_path, SZ_PATHNAME) <= 0)
+                strcpy (xc_path, XC);
 
 
 	if (debug > 1) {
@@ -891,10 +908,7 @@ do_link (struct context *cx)
 	} else
 	    lflags = getsym (LFLAGS);
 
-	if (irafdir[0])
-	    sprintf (cmd, "%s %s -r %s", XC, lflags, irafdir);
-	else
-	    sprintf (cmd, "%s %s", XC, lflags);
+	sprintf (cmd, "%s %s", xc_path, lflags);
 
 	if (debug)
 	    strcat (cmd, " -d");
@@ -929,6 +943,8 @@ do_link (struct context *cx)
 	    exit_status = h_xc (cmd);
 	if (exit_status == INTERRUPT)
 	    fatals ("<ctrl/c> interrupt %s", cx->library);
+	if (exit_status != OK)
+	    errors ("Command '%s' returned error", cmd);
 
 	skip_sf = 0;
 	return (exit_status);
@@ -941,13 +957,18 @@ int
 do_generic (struct context *cx)
 {
 	char	cmd[SZ_CMD+1];
+	static  char generic_path[SZ_PATHNAME+1];
+
+        if (!generic_path[0])
+            if (os_sysfile (GENERIC, generic_path, SZ_PATHNAME) <= 0)
+                strcpy (generic_path, GENERIC);
 
 	if (debug > 1) {
 	    printf ("do_generic:\n");
 	    fflush (stdout);
 	}
 
-	getcmd (cx, GENERIC, cmd, SZ_CMD);
+	getcmd (cx, generic_path, cmd, SZ_CMD);
 
 	if (ifstate[iflev] == STOP)
 	    return 0;
@@ -961,6 +982,46 @@ do_generic (struct context *cx)
 	    exit_status = os_cmd (cmd);
 	if (exit_status == INTERRUPT)
 	    fatals ("<ctrl/c> interrupt %s", cx->library);
+	if (exit_status != OK)
+	    errors ("Command '%s' returned error", cmd);
+
+	return (exit_status);
+}
+
+
+/* DO_XYACC -- Call the xyacc parser generator
+ */
+int
+do_xyacc (struct context *cx)
+{
+	char	cmd[SZ_CMD+1];
+	static  char xyacc_path[SZ_PATHNAME+1];
+
+        if (!xyacc_path[0])
+            if (os_sysfile (XYACC, xyacc_path, SZ_PATHNAME) <= 0)
+                strcpy (xyacc_path, XYACC);
+
+	if (debug > 1) {
+	    printf ("do_xyacc:\n");
+	    fflush (stdout);
+	}
+
+	getcmd (cx, xyacc_path, cmd, SZ_CMD);
+
+	if (ifstate[iflev] == STOP)
+	    return 0;
+
+	if (verbose) {
+	    printf ("%s\n", cmd);
+	    fflush (stdout);
+	}
+
+	if (execute)
+	    exit_status = os_cmd (cmd);
+	if (exit_status == INTERRUPT)
+	    fatals ("<ctrl/c> interrupt %s", cx->library);
+	if (exit_status != OK)
+	    errors ("Command '%s' returned error", cmd);
 
 	return (exit_status);
 }
@@ -1013,7 +1074,7 @@ do_incheck (struct context *cx)
 
 	exit_status = h_incheck (fname, dname);
 	if (exit_status != OK)
-	    warns ("error during checkin of %s", fname);
+	    errors ("error during checkin of %s", fname);
 
 	return (exit_status);
 }
@@ -1038,7 +1099,7 @@ do_outcheck (struct context *cx)
 
 	exit_status = h_outcheck (fname, dname, clobber=YES);
 	if (exit_status != OK)
-	    warns ("error during checkout of %s", fname);
+	    errors ("error during checkout of %s", fname);
 
 	return (exit_status);
 }
@@ -1070,7 +1131,7 @@ do_copyfile (struct context *cx)
 	
 	exit_status = h_copyfile (old, new);
 	if (exit_status != OK)
-	    warns ("error making copy of %s", old);
+	    errors ("error making copy of %s", old);
 
 	return (exit_status);
 }
@@ -1113,7 +1174,7 @@ do_movefile (struct context *cx)
 	
 	exit_status = h_movefile (old, new);
 	if (exit_status != OK)
-	    warns ("error moving file %s", old);
+	    errors ("error moving file %s", old);
 
 	return (exit_status);
 }
@@ -1148,7 +1209,7 @@ do_delete (struct context *cx)
 
 		exit_status = os_delete (fname);
 		if (exit_status != OK)
-		    warns ("cannot delete file %s", fname);
+		    errors ("cannot delete file %s", fname);
 	    }
 	}
 }
@@ -1173,7 +1234,7 @@ do_purge (
 
 	exit_status = h_purge (dname);
 	if (exit_status != OK)
-	    warns ("error during purge of %s", dname);
+	    errors ("error during purge of %s", dname);
 }
 
 
@@ -1294,7 +1355,7 @@ getstr (
 	    } else if (ch == '\n' || ch == EOF) {
 		*op = EOS;
 		if (delim != ' ')
-		    warns ("missing closing quote in string `%s'", outstr);
+		    errors ("missing closing quote in string `%s'", outstr);
 		m_ungetc ('\n', cx);
 		break;
 	    } else
@@ -1330,7 +1391,7 @@ getkwvpair (
 	    if (ch == ' ') {
 		continue;
 	    } else if (ch == '\n') {
-		warns ("missing `=' in $set statement `%s'", symbol);
+		errors ("missing `=' in $set statement `%s'", symbol);
 		m_ungetc ('\n', cx);
 		return (ERR);
 	    } else
