@@ -4,9 +4,7 @@
 #include "ratdef.h"
 
 FINT
-GETLIN(line, fd)
-RCHAR	*line;
-FINT	*fd;
+GETLIN(RCHAR *line, FINT *fd)
 {
 	register  int c=0;
 	register  int count=0;
