@@ -25,7 +25,7 @@
  * system.
  */
 
-#define VERSION		"IRAFNET XC V2.4 Jan 21 2010"
+#define VERSION		"IRAF community XC V2.5 Mar 15 2023"
 
 #define	ERR		(-1)
 #define	EOS		'\0'
@@ -41,14 +41,12 @@
 #define	SZ_PKGENV	256
 #define DEF_PKGENV	"iraf"
 
-#if (defined (__APPLE__) || defined (__freebsd__))
 #define	CCOMP		"cc"			/* C compiler (also .s etc.) */
 #define	LINKER		"cc"			/* Linking utility */
+#if (defined (__APPLE__) || defined (__freebsd__))
 #define	F_STATIC	"-static"
 #define	F_SHARED	"-shared"
 #else
-#define	CCOMP		"gcc"			/* C compiler (also .s etc.) */
-#define	LINKER		"gcc"			/* Linking utility */
 #define	F_STATIC	"-Wl,-Bstatic"
 #define	F_SHARED	"-Wl,-Bdynamic"
 #endif
@@ -85,7 +83,7 @@ char *fortlib[] = { "-lf2c",			/*  0  (host progs) */
 #else
 		    "",				/*  5  */
 #endif
-		    "",				/*  6  */		    
+		    "-lz",			/*  6  */
 		    "",				/*  7  */
 		    "",				/*  8  */
 		    "",				/*  9  */
@@ -130,7 +128,6 @@ int	nolibc 		= NO;
 int	usef2c 		= YES;
 int	useg95 		= NO;
 int	userincs	= NO;
-int	useg2c 		= NO;
 int	host_c_main 	= NO;
 
 char	ccomp[SZ_FNAME] 	= CCOMP;
@@ -184,8 +181,8 @@ static int   run (char *task, char *argv[]);
 static int   sys (char *cmd);
 
 static void  done (int k);
-static void  enbint (SIGFUNC handler);
-static void  interrupt (void);
+static void  enbint (void (*handler)(int));
+static void  interrupt (int);
 static int   await (int waitpid);
 static void  rmfiles (void);
 
@@ -202,9 +199,9 @@ static void  fatal (char *s);
  *	f77		UNIX fortran compiler
  *	cc		compile other sources, link if desired
  *
- *  The Fortran source is left behind if the -F flag is given.  The IRAF root
- *  directory must either be given on the command line as "-r pathname" or in
- *  the environment as the variable "irafdir".
+ *  The Fortran source is left behind if the -F flag is given.  The
+ *  IRAF root directory must be given in the environment as the
+ *  variable "iraf".
  */
 int
 main (int argc, char *argv[])
@@ -232,23 +229,30 @@ main (int argc, char *argv[])
 	sig_hup  = (long) signal (SIGHUP,  SIG_IGN) & 01;
 	sig_term = (long) signal (SIGTERM, SIG_IGN) & 01;
 
-	enbint ((SIGFUNC)interrupt);
+	enbint (interrupt);
 	pid = getpid();
 
-	/* Load any XC related environment definitions.
+	/* Load general environment definitions.
+	 */
+	if ((s = os_getenv ("CC"))) {
+	    strcpy (ccomp, s);
+	    strcpy (linker, s);
+	}
+	if ((s = os_getenv ("F77")))
+	    strcpy (f77comp, s);
+
+	/* Load any XC specific environment definitions.
 	 */
 	if ((s = os_getenv ("XC-CC")) || (s = os_getenv ("XC_CC")))
 	    strcpy (ccomp, s);
-	if ((s = os_getenv ("XC-F77")) || (s = os_getenv ("XC_F77"))) {
+	if ((s = os_getenv ("XC-F77")) || (s = os_getenv ("XC_F77")))
 	    strcpy (f77comp, s);
-	    usef2c = (strncmp (f77comp, "f77", 3) == 0 ? 1 : 0);
-	    useg95 = (strncmp (f77comp, "g95", 3) == 0 ? 1 : 0);
-	}
+	usef2c = (strncmp (f77comp, "f77", 3) == 0 ? 1 : 0);
+	useg95 = (strncmp (f77comp, "g95", 3) == 0 ? 1 : 0);
 	if ((s = os_getenv ("XC-LINKER")) || (s = os_getenv ("XC_LINKER")))
 	    strcpy (linker, s);
 
 
-
         /* Always load the default IRAF package environment. */
 	loadpkgenv (DEF_PKGENV);
 
@@ -389,12 +393,6 @@ main (int argc, char *argv[])
 		    i++;
 		    break;
 
-		case 'r':
-		    /* Not used anymore */
-		    if ((arg = argv[++i]) == NULL)
-			i--;
-		    break;
-
 		case 'h':
 		    /* Host program: do not link in IRAF main or search
 		     * standard IRAF libraries unless explicitly referenced
@@ -411,12 +409,6 @@ main (int argc, char *argv[])
 		    nolibc++;
 		    break;
 
-		case 'G':
-		    /* Force a program to link w/ libg2c.a instead of libf2c.a
-		     */
-		    useg2c++;
-		    break;
-
 		case 'A':
 		    /* Force arch-specific include files.
 		     */
@@ -613,16 +605,6 @@ passflag:		    mkobject = YES;
 	    }
 	}
 
-	/* Now check for any alternative compiler definitions or commandline
-	 * flags which will affect out link line.  Some systems like LinuxPPC
-	 * will require use of -lg2c even though we can continue to use the
-	 * hlib$f77.sh the fortran compiler script on that system.
-	 */
-	if (useg2c || strncmp (f77comp, "g77", 3) == 0) {
-	    fortlib[0] = fortlib[1] = "-lg2c";
-	}
-
-
 	/* Compile all F77 source files with F77 to produce object code.
 	 * This compilation is separate from that used for the '.x' files,
 	 * because we do not want to use the UNIX "-u" flag (requires that
@@ -734,6 +716,11 @@ passflag:		    mkobject = YES;
 	        arglist[nargs++] = opt_flags[i];
 	}
 
+	if (! nolibc) {
+	    addflags ("-I", arglist, &nargs);
+	    addflags (vfn2osfn(LIBCINCLUDES, 0), arglist, &nargs);
+	}
+
 	/* Add the user-defined flags last so they can override the 
 	 * hardwired options.
 	 */
@@ -988,7 +975,8 @@ addflags (char *flag, char *arglist[], int *p_nargs)
 		        *p_nargs = nargs;
 		        return (1);
 	        }
-	        arglist[nargs++] = fs;
+		if (strlen(fs))
+		    arglist[nargs++] = fs;
 	    }
 
 	    *p_nargs = nargs;
@@ -1318,7 +1306,7 @@ done (int k)
  * of interrupt occurs.
  */
 static void
-enbint (SIGFUNC handler)
+enbint (void (*handler)(int))
 {
 	if (sig_int == 0)
 	    signal (SIGINT, handler);
@@ -1335,7 +1323,7 @@ enbint (SIGFUNC handler)
  * during compilation.
  */
 static void
-interrupt (void)
+interrupt (int signum)
 {
 	done (2);
 }
@@ -1352,7 +1340,7 @@ await (int waitpid)
 	while ((w = wait (&status)) != waitpid)
 	    if (w == -1)
 		fatal ("bad wait code");
-	enbint ((SIGFUNC)interrupt);
+	enbint (interrupt);
 	if (status & 0377) {
 	    if (status != SIGINT) {
 		fprintf (stderr, "Termination code %d", status);
