@@ -415,7 +415,7 @@ enddcl(Void)
 	freetemps();
 	if (earlylabs) {
 		for(cp = earlylabs = revchain(earlylabs); cp; cp = cp->nextp)
-			p1_label((long)cp->datap);
+			p1_label((Addr)cp->datap);
 		frchain(&earlylabs);
 		}
 	p1_line_number(lineno); /* for files that start with a MAIN program */
@@ -1138,7 +1138,7 @@ copy_data(chainp list)
 	    namep -> vleng = (expptr) cpexpr (namep -> vleng);
 	if (namep -> vdim) {
 	    nd = namep -> vdim -> ndim;
-	    size = sizeof(struct Dimblock) + 2 * nd * sizeof(expptr);
+	    size = sizeof(struct Dimblock) + 2*sizeof(expptr)*(nd-1);
 	    dp = (struct Dimblock *) ckalloc (size);
 	    cpn(size, (char *)namep->vdim, (char *)dp);
 	    namep -> vdim = dp;
@@ -1690,7 +1690,7 @@ setbound(Namep v, int nd, struct Dims *dims)
 	}
 
 	v->vdim = p = (struct Dimblock *)
-	    ckalloc( sizeof(struct Dimblock) + 2 * nd * sizeof(expptr) );
+	    ckalloc( sizeof(struct Dimblock) + 2*sizeof(expptr)*(nd-1) );
 	p->ndim = nd--;
 	p->nelt = ICON(1);
 	doin_setbound = 1;
