@@ -13,6 +13,8 @@
 #define import_finfo
 #include <iraf.h>
 
+#include "osproto.h"
+
 /* ZFINFO -- Get information describing the named file.  Access times
  * are returned in units of seconds since 00:00:00 01-Jan-80, local time.
  */
@@ -37,11 +39,11 @@ ZFINFO (
 
 	/* Determine file type.
 	 */
-	if (osfile.st_mode & S_IFDIR)
+	if (S_ISDIR(osfile.st_mode))
 	    fs->fi_type = FI_DIRECTORY;
-	else if (osfile.st_mode & S_IEXEC)
+	else if (osfile.st_mode & S_IXUSR)
 	    fs->fi_type = FI_EXECUTABLE;
-	else if (osfile.st_mode & S_IFREG)
+	else if (S_ISREG(osfile.st_mode))
 	    fs->fi_type = FI_REGULAR;
 	else
 	    fs->fi_type = FI_SPECIAL;
