@@ -30,6 +30,8 @@
 #define import_spp
 #include <iraf.h>
 
+#include "osproto.h"
+
 
 /* ZFIOKS -- File i/o to a remote kernel server.  This driver is the network
  * interface for the kernel interface package (sys$ki).  The KS driver is
@@ -159,14 +161,14 @@ static	jmp_buf jmpbuf;
 static	int jmpset = 0;
 static	int recursion = 0;
 static	int parent = -1;
-static	SIGFUNC old_sigcld;
+static	void (*old_sigcld)(int);
 static  int ks_pchan[MAXOFILES];
 static  int ks_achan[MAXOFILES];
 static	int ks_getresvport(int *alport), ks_rexecport(void);
 static	int ks_socket(char *host, u_long addr, int port, char *mode), ks_geti(int fd), ks_puti(int fd, int ival), ks_getlogin(char *hostname, char *loginname, char *password, struct ksparam *ks);
 static	void dbgsp(int pid), dbgmsg(char *msg), dbgmsgf(char *fmt, ...);
 static	char *ks_getpass(char *user, char *host);
-static	void ks_onsig(int sig, int *arg1, int *arg2), ks_reaper(int sig, int *arg1, int *arg2);
+static	void ks_onsig(int sig), ks_reaper(int sig);
 
 static int ks_getlogin (char *hostname, char *loginname, char *password,
   				struct ksparam *ks);
@@ -444,7 +446,7 @@ d_err:		dbgmsgf ("S:in.irafksd parent exit, status=%d\n", status);
 
 	    dbgmsgf ("S:in.irafksd started, pid=%d ppid=%d\n",
 		getpid(), getppid());
-	    old_sigcld = (SIGFUNC) signal (SIGCHLD, (SIGFUNC)ks_reaper);
+	    old_sigcld = signal (SIGCHLD, ks_reaper);
 
 	    /* Reset standard streams to console to record error messages. */
 	    fd = open ("/dev/null",    O_RDONLY); close(0); dup(fd); close(fd);
@@ -542,7 +544,7 @@ s_err:		    dbgmsgf ("S:in.irafksd fork complete, status=%d\n",
 			getpid(), getppid());
 		    signal (SIGCHLD, old_sigcld);
 		    /*
-		    old_sigcld = (SIGFUNC) signal (SIGCHLD, (SIGFUNC)ks_reaper);
+		    old_sigcld = signal (SIGCHLD, ks_reaper);
 		    */
 		    close (fd); close (s);
 
@@ -915,7 +917,7 @@ ZARDKS (
 	char	*op;
 	int	fd, nbytes;
 #endif
-	SIGFUNC	sigint, sigterm;
+	void	(*sigint)(int), (*sigterm)(int);
 	int	status = ERR;
 
 	fd = *chan;
@@ -931,8 +933,8 @@ ZARDKS (
 	 * entire record.  Reads are interruptable but the interrupt is caught
 	 * and returned as a read error on the server channel.
 	 */
-	sigint  = (SIGFUNC) signal (SIGINT,  (SIGFUNC)ks_onsig);
-	sigterm = (SIGFUNC) signal (SIGTERM, (SIGFUNC)ks_onsig);
+	sigint  = signal (SIGINT,  ks_onsig);
+	sigterm = signal (SIGTERM, ks_onsig);
 
 	while (nbytes > 0) {
 	    jmpset++;
@@ -975,7 +977,7 @@ ZAWRKS (
   XLONG	*loffset 		/* not used				*/
 )
 {
-	SIGFUNC	sigint, sigterm, sigpipe;
+  void	(*sigint)(int), (*sigterm)(int), (*sigpipe)(int);
 #ifdef ANSI
 	volatile int fd, nbytes;
 	volatile int ofd;
@@ -1001,9 +1003,9 @@ ZAWRKS (
 	 * Trap SIGPIPE and return it as a write error on the channel instead.
 	 * Likewise, turn an interrupt into a write error on the channel.
 	 */
-	sigint  = (SIGFUNC) signal (SIGINT,  (SIGFUNC)ks_onsig);
-	sigterm = (SIGFUNC) signal (SIGTERM, (SIGFUNC)ks_onsig);
-	sigpipe = (SIGFUNC) signal (SIGPIPE, (SIGFUNC)ks_onsig);
+	sigint  = signal (SIGINT,  ks_onsig);
+	sigterm = signal (SIGTERM, ks_onsig);
+	sigpipe = signal (SIGPIPE, ks_onsig);
 	recursion = 0;
 
 	jmpset++;
@@ -1027,9 +1029,7 @@ ZAWRKS (
  */
 static void
 ks_onsig (
-  int	sig,			/* signal which was trapped	*/
-  int	*arg1,			/* not used */
-  int	*arg2 			/* not used */
+  int	sig			/* signal which was trapped	*/
 )
 {
 	/* If we get a SIGPIPE writing to a server the server has probably
@@ -1047,9 +1047,7 @@ ks_onsig (
  */
 static void
 ks_reaper (
-  int     sig,                  /* signal which was trapped     */
-  int     *arg1,                /* not used */
-  int     *arg2                 /* not used */
+  int     sig                  /* signal which was trapped     */
 )
 {
         int status=0, pid=0;
@@ -1618,10 +1616,8 @@ ks_sysname (char *filename, char *pathname)
 {
 	XCHAR	irafdir[SZ_PATHNAME+1];
 	XINT	x_maxch=SZ_PATHNAME, x_nchars;
-	extern  int  ZGTENV(PKCHAR *envvar, PKCHAR *outstr, XINT *maxch, XINT *status);
 
-
-	ZGTENV ("iraf", irafdir, &x_maxch, &x_nchars);
+	ZGTENV ((const int*)"iraf", irafdir, &x_maxch, &x_nchars);
 	if (x_nchars <= 0)
 	    return (NULL);
 
