@@ -5,6 +5,7 @@
 #include <sys/stat.h>
 #include <sys/file.h>
 #include <sys/socket.h>
+#include <sys/time.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <sys/un.h>
@@ -23,6 +24,8 @@
 #define import_spp
 #include <iraf.h>
 
+#include "osproto.h"
+
 /*
  * ZFIOND -- This driver provides a FIO-compatible interface to network or
  * IPC streaming devices such as Berkeley sockets, FIFOs, and the like.
@@ -156,8 +159,7 @@ static	int recursion = 0;
 extern	int errno;
 static	int getstr(char **ipp, char *obuf, int maxch, int delim);
 
-static void nd_onsig (int sig, int *arg1, int *arg2);
-
+static void nd_onsig (int sig);
 
 
 /* ZOPNND -- Open a network device.
@@ -223,7 +225,7 @@ ZOPNND (
 		    if (host_addr == INADDR_NONE)
 			goto err;
 		} else if ((hp = gethostbyname(host_str))) {
-  		    memcpy (&host_addr, hp->h_addr, sizeof(host_addr));
+ 		    memcpy (&host_addr, hp->h_addr_list[0], sizeof(host_addr));
 		} else
 		    goto err;
 
@@ -739,12 +741,12 @@ ZAWRND (
 	int nwritten, maxbytes, n;
 	char *text, *ip = (char *)buf;
 	char obuf[SZ_OBUF];
-	SIGFUNC sigpipe;
+	void (*sigpipe)(int);
 
 
 	/* Enable a signal mask to catch SIGPIPE when the server has died. 
 	 */
-	sigpipe = (SIGFUNC) signal (SIGPIPE, (SIGFUNC)nd_onsig);
+	sigpipe = signal (SIGPIPE, nd_onsig);
 	recursion = 0;
 
 	maxbytes = (np->domain == FIFO || (np->flags & F_TEXT)) ? SZ_OBUF : 0;
@@ -798,9 +800,7 @@ ZAWRND (
  *  */
 static void
 nd_onsig (
-  int     sig,                    /* signal which was trapped     */
-  int     *arg1,                  /* not used */
-  int     *arg2                   /* not used */
+  int     sig                    /* signal which was trapped     */
 )
 {
         /* If we get a SIGPIPE writing to a server the server has probably
