@@ -13,6 +13,8 @@
 #define import_spp
 #include <iraf.h>
 
+#include "osproto.h"
+
 /*
  * ZFIOPL -- IRAF FIO interface to plotter devices.  A plotter
  * is opened as a streaming type (no seeks) write-only binary device.
@@ -60,16 +62,6 @@ char	plstr[SZ_PLSTR+1];		/* save zopnpl argument		*/
 int	pltr_inuse = NO;		/* set if plotter is open	*/
 
 
-extern  int ZOPNBF (PKCHAR *osfn, XINT *mode, XINT *chan);
-extern	int ZCLSBF (XINT *fd, XINT *status);
-extern	int ZOSCMD (PKCHAR *oscmd, PKCHAR *stdin_file, PKCHAR  *stdout_file, PKCHAR *stderr_file, XINT *status);
-extern	int ZFDELE (PKCHAR *fname, XINT *status);
-extern	int ZARDBF (XINT *chan, XCHAR *buf, XINT *maxbytes, XLONG *offset);
-extern  int ZAWRBF (XINT *chan, XCHAR *buf, XINT *nbytes, XLONG *offset);
-extern	int ZAWTBF (XINT *fd, XINT *status);
-extern	int ZSTTBF (XINT *fd, XINT *param, XLONG *lvalue);
-
-
 /* ZOPNPL -- Open a plotter device for binary file i/o.  If we can talk
  * directly to the plotter, do so, otherwise open a spoolfile which is
  * to be sent to the plotter when ZCLSPL is later called.
