@@ -15,15 +15,17 @@
 #define import_prtype
 #define	import_knames
 #define	import_xnames
+#define import_kproto
 #include <iraf.h>
 
+extern	int  ONENTRY(XINT *prtype, XCHAR *bkgfile, XCHAR *cmd);
+extern	int  SYSRUK(XCHAR *task, XCHAR *cmd, XINT *rukarf, XINT *rukint);
+extern	int  ZZSETK(char *ospn, char *osbfn, int prtype, int isatty, int in, int out);
+
+
 /*
  * ZMAIN.C -- C main for IRAF processes.
  */
-
-extern	unsigned USHLIB[];
-extern	int sh_debug;
-
 #define	LOGIPC	"LOGIPC"		/* define to enable IPC logging. */
 
 static	char os_process_name[SZ_FNAME];
@@ -62,14 +64,6 @@ main (int argc, char *argv[])
 	char	*ip;
 
 	int	arg = 1;
-	extern  int  ZGETTX(XINT *fd, XCHAR *buf, XINT *maxchars, XINT *status);
-	extern	int  ZGETTY(XINT *fd, XCHAR *buf, XINT *maxchars, XINT *status);
-	extern	int  ZARDPR(XINT *chan, XCHAR *buf, XINT *maxbytes, XLONG *loffset);
-	extern	int  SYSRUK(XCHAR *task, XCHAR *cmd, XINT *rukarf, XINT *rukint);
-	extern	int  ONENTRY(XINT *prtype, XCHAR *bkgfile, XCHAR *cmd);
-	extern  int  ZZSTRT(void);
-	extern	int  ZLOCPR(PFI proc, XINT *o_epa );
-	extern	int  ZZSETK(char *ospn, char *osbfn, int prtype, int isatty, int in, int out);
 	extern	int  IRAF_MAIN(XCHAR *acmd, XINT *ainchn, XINT *aoutcn, XINT *aerrcn, XINT *adrivr, XINT *adevte, XINT *prtype, XCHAR *bkgfie, XINT *jobcoe,
 			       int(sysruk)(XCHAR *task, XCHAR *cmd, XINT *rukarf, XINT *rukint),
 			       int(onenty)(XINT *prtype, XCHAR *bkgfile, XCHAR *cmd));
@@ -77,7 +71,6 @@ main (int argc, char *argv[])
 
 	/* The following flag must be set before calling ZZSTRT. */
 	if (argc > 1 && strcmp (argv[arg], "-w") == 0) {
-	    sh_debug++;
 	    arg++;
 	}
 
@@ -96,7 +89,7 @@ main (int argc, char *argv[])
 
         /* Default if no arguments (same as -h, or host process). */
 	prtype = PR_HOST;
-	ZLOCPR (ZGETTY, &driver);
+	ZLOCPR ((funcptr_t)ZGETTY, &driver);
 	devtype = TEXT_FILE;
 
 	if (arg < argc) {
@@ -125,7 +118,7 @@ main (int argc, char *argv[])
 
 ipc_:
 		prtype = PR_CONNECTED;
-		ZLOCPR (ZARDPR, &driver);
+		ZLOCPR ((funcptr_t)ZARDPR, &driver);
 		devtype = BINARY_FILE;
 
 	    } else if (strcmp (argv[arg], "-d") == 0) {
@@ -145,7 +138,7 @@ ipc_:
 		setpgid (0, jobcode);
 		freopen ("/dev/null", "r", stdin);
 		prtype = PR_DETACHED;
-		ZLOCPR (ZGETTX, &driver);
+		ZLOCPR ((funcptr_t)ZGETTX, &driver);
 		devtype = TEXT_FILE;
 
 		/* Copy the bkgfile to PKCHAR buffer to avoid the possibility
@@ -194,7 +187,7 @@ ipc_:
 	 * code only in the event of a panic.
 	 */
 	errstat = IRAF_MAIN (irafcmd, &inchan, &outchan, &errchan,
-	    &driver, &devtype, &prtype, osfn_bkgfile, &jobcode, SYSRUK,ONENTRY);
+			     &driver, &devtype, &prtype, (XCHAR*)osfn_bkgfile, &jobcode, SYSRUK,ONENTRY);
 
 	/* Normal process shutdown.  Our only action is to delete the bkgfile
 	 * if run as a detached process (see also zpanic).
