@@ -13,6 +13,8 @@
 #define import_xwhen
 #include <iraf.h>
 
+#include "osproto.h"
+
 /* ZXWHEN.C -- IRAF exception handling interface.  This version has been 
  * customized for PC-IRAF, i.e., LINUX and FreeBSD.
  *
@@ -36,9 +38,13 @@ int debug_sig = 0;
 #define	fcancel(fp)
 #endif
 
-void ex_handler ( int, siginfo_t *, void * );
+typedef void  (*SIGFUNC)(XINT *, XINT *);
+typedef	void  (*sigaction_t)(int, siginfo_t *, void *);
+typedef void  (*sighandler_t)(int);
+
+static void ex_handler (int, siginfo_t *, void *);
+static sighandler_t setsig(int, sigaction_t);
 
-static long setsig(int code, SIGFUNC handler);
 static int ignore_sigint = 0;
 
 
@@ -181,9 +187,7 @@ ZXWHEN (
 {
 	static	int first_call = 1;
 	int     vex, uex;
-	SIGFUNC	vvector;
-
-	extern  int  kernel_panic (char *errmsg);
+	sigaction_t vvector;
 
 
 	/* Convert code for virtual exception into an index into the table
@@ -203,13 +207,13 @@ ZXWHEN (
 	    
 	*old_epa = handler_epa[vex];
 	handler_epa[vex] = *epa;
-	vvector = (SIGFUNC) ex_handler;
+	vvector = ex_handler;
 
 	/* Check for attempt to post same handler twice.  Do not return EPA
 	 * of handler as old_epa as this could lead to recursion.
 	 */
 	if (*epa == (XINT) X_IGNORE)
-	    vvector = (SIGFUNC) SIG_IGN;
+	  vvector = (sigaction_t)SIG_IGN;
 	else if (*epa == *old_epa)
 	    *old_epa = (XINT) X_IGNORE;
 
@@ -222,20 +226,20 @@ ZXWHEN (
 	    if (unix_exception[uex].x_vex == *sig_code) {
 		if (uex == SIGINT) {
 		    if (first_call) {
-			if (setsig (uex, vvector) == (long) SIG_IGN) {
-			    setsig (uex, SIG_IGN);
+			if (setsig (uex, vvector) == SIG_IGN) {
+			    setsig (uex, (sigaction_t)SIG_IGN);
 			    ignore_sigint++;
 			}
 			first_call = 0;
 		    } else if (!ignore_sigint) {
 			if (debug_sig)
-			    setsig (uex, SIG_DFL);
+			    setsig (uex, (sigaction_t)SIG_DFL);
 			else
 			    setsig (uex, vvector);
 		    }
 		} else {
 		    if (debug_sig)
-			setsig (uex, SIG_DFL);
+			setsig (uex, (sigaction_t)SIG_DFL);
 		    else
 			setsig (uex, vvector);
 		}
@@ -248,22 +252,24 @@ ZXWHEN (
 
 /* SETSIG -- Post an exception handler for the given exception.
  */
-static long
-setsig (int code, SIGFUNC handler)
+static sighandler_t
+setsig(int code, sigaction_t action)
 {
-	struct sigaction sig;
-	long status;
+	struct sigaction sig, old_sig;
+	int status;
 
 	sigemptyset (&sig.sa_mask);
-#ifdef __APPLE__
-	sig.sa_handler = (SIGFUNC) handler;
-#else
-	sig.sa_sigaction = (SIGFUNC) handler;
-#endif
-	sig.sa_flags = (SA_NODEFER|SA_SIGINFO);
-	status = (long) sigaction (code, &sig, NULL);
+	if ((action != (sigaction_t)SIG_DFL)
+	  && (action != (sigaction_t)SIG_IGN)) {
+	  sig.sa_sigaction = action;
+	  sig.sa_flags = SA_NODEFER|SA_SIGINFO;
+	} else {
+	  sig.sa_handler = (sighandler_t)action;
+	  sig.sa_flags = SA_NODEFER;
+	}
+	status = sigaction (code, &sig, &old_sig);
 
-	return (status);
+	return (status == 0)? old_sig.sa_handler: NULL;
 }
 
 
@@ -273,7 +279,7 @@ setsig (int code, SIGFUNC handler)
  * handler.  If we get the software termination signal from the CL, 
  * stop process execution immediately (used to kill detached processes).
  */
-void
+static void
 ex_handler (
   int  	    unix_signal,
   siginfo_t *info,
